/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package org.glassfish.websockets.api;

import javax.servlet.http.HttpSession;
import java.util.*;
import java.io.*;

/**
 * A Conversation represents the sequence of bi-directional messages between an end point 
 * and one of its remote peers. It's a bit like the web socket equivalent of an HttpSession
 * in servlet programming.
 * @author dannycoward
 */


public interface Conversation {
    /** Obtain a reference to the remote object with which this
     * conversation is happening. */
     
    public Peer getRemote();
    /** Test whether this conversation is active. I.e. is the underlying
     * websocket connection alive or not.
     * @return 
     */
    public boolean isActive();
    
    /** Return the time when this conversation started.*/
    public Date getActivationTime();
    
    /** Return the web socket sub protocol used in this conversation, as agreed in the
     * initial handshake.
     * @return 
     */
    public String getSubprotocol();
    
    /** Obtain the HttpSession that this web socket conversation is part of, if embedded in
     * a servlet container. Otherwise, null. For example, if this conversation was initiated by 
     * a javascript web socket call from a JSP page, then the HttpSession is the HttpSession
     * that was created when the JSP was first called.
     * @return 
     */
    public HttpSession getHttpSession();
     /** A read/write map of properties. An end point may use this to share
     * data throughout the lifetime of web socket conversation.
     * @return 
     */
    public Map getProperties();
    
     /** Return a unique ID for this conversation.*/
    public Long getConversationID();
    
    /** Closes the underlying connection this session is based upon.*/
    public void deactivate() throws IOException;
}
