/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package org.glassfish.websockets.api;

import java.util.*;

/**
 * Each web socket end point has one and only one EndpointContext object. From this object
 * the end point can obtain all the active conversations this end point is part of. The
 * EndpointContext can be used to store data that is sharable across all conversations. 
 * @author dannycoward
 */
public interface EndpointContext {
    /** Obtain a collection of all the active conversations
     * the end point to which this EndpointContext is associated. For example, in
     * a chat application, this call will return a collection of conversation
     * objects representing all the active web socket connections to the
     * end point.
     * @return 
     */
    public Set<Conversation> getConversations();
    /** Get a reference to the container context to which this context belongs. */
    public ContainerContext getContainerContext();
     /** A read/write map of properties. Applications may use this to share
     * application data throughout the lifetime of this web socket end point.
     * @return 
     */
    public Map getProperties();
    
    /** Obtain the URI relative to the root of the web socket runtime for the end point to which this context belongs. For example,
     if the web socket is at ws:/example.com/hello, this call returns "/hello". */
    public String getPath();
    
}
