
package org.glassfish.websockets.api;

import java.io.*;
import java.net.*;

/**
 * An object that represents the 'other end' of the web socket conversation
 * with a web socket end point.
 * @author dannycoward
 */

public interface Peer {
    /** Return the context of the end point that this remote is a peer of
     * in a web socket conversation.
     * @return 
     */
    public EndpointContext getContext();
    /** Return the conversation to which this remote peer is part of.*/
    public Conversation getConversation();
    /** Send a message to the remote peer this object represents.*/
    public void sendMessage(String data) throws IOException;
    /** Send a message to the remote peer this object represents.*/
    public void sendMessage(byte[] data) throws IOException;
    /** Close this remote object. i.e. end the conversation, close the underlying
     * web socket connection.*/
    public void doClose(int code, String reason) throws IOException; 
    /** Test whether this remote object is active, i.e. the underlying web
     * socket connection which connects the remote peer is open or not.
     * @return 
     */
    public boolean isConnected();
    /** Obtain the remote address of the remote peer. This is obtained from
     * the initial web socket handshake ( the 'Origin' header ).
     * @return 
     */
    public String getAddress();
}
