package org.glassfish.websockets.api;

/*
 * For developers who would rather implement an interface than
 * use annotations, here is an interface that can be implemented
 * to make an end point.
 */

/**
 *
 * @author dannycoward
 */
public interface WSEndpoint {
    /** Called when this end point instance is first published
     * and before it accepts any connections. You can deploy instances
     * of these end points to a relative URI on the ContainerContext.
     *  
     */
    public void initialize(EndpointContext epcontext);
    /** Called whenever a peer first connects to this end point.*/
    public void onOpen(Peer p);
    /** Called when a peer sends a text message to this end point.*/
    public void onMessage(Peer p, String message);
    /** Called when a peer sends a binary message to this end point.*/
    public void onMessage(Peer p, byte[] data);
    /** Called when a peer disconnects from this end point.*/
    public void onClose(Peer p, CloseEvent ce);
    /** Called when there us an error on the connection from the supplied peer 
     * to this end point.
     * @param p
     * @param e 
     */
    public void onError(Peer p, Exception e);
    /** Called by the container when this end point is about to be taken out of 
     * service.
     */
    public void remove();
    
}
