/*
 * To change this template, choose Tools | Templates and open the template in
 * the editor.
 */
package org.glassfish.websockets.api.annotations;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

/**
 *  This is the annotation you need to use at the class level of your end point to declare 
 * that this class will have methods that accept web socket messages. 
 * This is the annotation you use to specify the URL path of the web socket.
 * <br>For example: <br>
 * <code><p>&nbsp&nbsp&nbsp@WebSocket(path="/hello") <br>
 * public class HelloSocket { <br>
 * &nbsp&nbsp&nbsp...<br>
 * }
 * </code>
 * @author dannycoward
 */
@Retention(RetentionPolicy.RUNTIME)
public @interface WebSocket {
    /** The relative URL to this end point. The path is relative to the
     * root of the URL-space of the host on which the end point is deployed. All
     * paths begin with "/".
     * @return 
     */
    String path();
    /**
     * An array of the subprotocols supported by this web socket end point, in descending
     * order of importance.
     * @return 
     */
    String[] subprotocols() default {};
    /** The Java type of the custom remote implementation used by this web socket end point.
     * 
     * @return 
     */
    String remote() default "";
}
