/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package org.glassfish.websockets.api.annotations;

import java.lang.annotation.*;

/**
 * Method level annotation indicating that this Java method will be called on an end point class 
 * when the end point receives a message. <br>
 * The Java method may have either one or two parameters. The first
 * parameter will encapsulate the incoming message, and may be of type String, byte[], any Java primitive 
 * or associated class-type. If the type of the parameter is not any of these types, the developer must provide
 * an encoder so the runtime can encode the incoming String or byte[] into the supplied type. The optional
 * second parameter must be of type WSRemote, and if present, this annotation's requireremote 
 * attribute must be true.<br>
 * The Java method may also have a non-void return type. If so, the runtime interprets this as a synchronous 
 * reply t the incoming message. The return type may be of type String, byte[], any Java primitive type or 
 * associated Java class, or a custom Java class provided a decoder class is provided.<br>
 * For example:<br>
 * <p>
 * <code>
 * &nbsp&nbsp&nbsp@WebSocketMessage<br>
    public void handleStringMessage(String message) {<br>
    &nbsp&nbsp&nbsp// process message 
    }
 * </code><br><br>
 * or...<br><br>
 * <code>
 * &nbsp&nbsp&nbsp@WebSocketMessage<br>
    public void handleNumber(Integer count) {<br>
    &nbsp&nbsp&nbsp// process count <br>
    }
 * </code>
 * <br><br>or...<br><br>
 *  <code>
 * &nbsp&nbsp&nbsp@WebSocketMessage<br>
    public String handleNumber(Integer count) {<br>
    &nbsp&nbsp&nbsp// process count <br>
 *  &nbsp&nbsp&nbspreturn "thanks for sending that wonderful number to me !";<br>
    }<br>
 * </code>
 * <br>or...<br><br>
 * <p>
 * <code>
 * &nbsp&nbsp&nbsp@WebSocketMessage(<br>
            &nbsp&nbsp&nbsp&nbsp&nbsp&nbsprequireremote=true)<br>
    public void handleSimpleMessage(String message, WSRemote client) {<br>
    &nbsp&nbsp&nbsp// process message object<br>
 *  &nbsp&nbsp&nbsp// log which client it's from<br>
    }<br><br>
 * </code>
 * or...
 * <p><code>
 * &nbsp&nbsp&nbsp@WebSocketMessage(<br>
   &nbsp&nbsp&nbsp&nbspencoder="enc.JSONEncoder",<br>
   &nbsp&nbsp&nbsp&nbspdecoder="enc.JSONDecoder")<br>
    public JSONObject helloWorld(JSONObject message) {<br>
    &nbsp&nbsp&nbsp// process message object<br>
 *  &nbsp&nbsp&nbsp// formulate reply object<br>
 *  &nbsp&nbsp&nbspreturn reply;<br>
    }<br>
 * </code>
 * @author dannycoward
 */
@Retention(RetentionPolicy.RUNTIME)
public @interface WebSocketMessage {
    /** If set to true, this indicates that the decorated Java method
     * has a WSRemote parameter to accept a reference to the calling client.
     * @return 
     */
    boolean requireremote() default false;
    /** The type of the decoder class the runtime must use to decode the return type of this message
     * into either a String or byte[].
     * @return 
     */
    String decoder() default "";
    /** The type of the encoder class the runtime must use to encode the incoming web socket
     * message into the custom type expected by the method in the first parameter.
     * @return 
     */
    String encoder() default "";
}
