/*
 * To change this template, choose Tools | Templates and open the template in
 * the editor.
 */
package org.glassfish.websockets.api.annotations;

/**
 * This method level annotation is used to indicate that a specific method
 * on a developer provided custom remote interface (i.e. one that extends
 * WSRemote) will be used to send a message to the remote client the interface
 * represents. The method may only have one parameter that represents the message
 * to be sent to the client. The type may be String, byte[], any Java primitive type
 * or corresponding Java class. Or the type may be a developer provided type, in which case
 * an encoder class must also be provided.
 * <br>For example:<br>
 * <code>
 * public interface MyCustomClient extends WSRemote {<br><br>
    
        &nbsp&nbsp&nbsp&nbsp&nbsp&nbsp@WebSocketRemote<br>
        &nbsp&nbsp&nbsppublic void sendStringMessage(String message) throws IOException, ConversionException;<br><br>
        
         &nbsp&nbsp&nbsp&nbsp&nbsp&nbsp@WebSocketRemote(<br>
         &nbsp&nbsp&nbsp&nbsp&nbsp&nbspencoder="wstestbeans.EncodedMessageEncoder")<br>
    &nbsp&nbsp&nbsppublic void sendEncodedMessage(EncodedMessage message) throws IOException, ConversionException;<br><br>

}
 * <br></code>

 * @author dannycoward
 */
public @interface WebSocketRemote {
    /** The fully qualified classname of the encoder
     * to be used to encode the message.
     * @return 
     */
    String encoder() default "";
}
